# pymemuc

A wrapper for [memuc](https://www.memuplay.com/blog/memucommand-reference-manual.html) in python.

See [pymemuc.md](docs/pymemuc.md) for package documentation.

See [memuc_documentation.md](docs/memuc_documentation.md) for a list of all commands.
